/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.archives.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.ColumnWidth;
import com.yifu.cloud.plus.v1.yifu.common.mybatis.base.BaseEntity;
import lombok.Data;

import java.time.LocalDateTime;

/**
 * 人员档案表excel导出对应的实体
 *
 * @author hgw
 * @date 2022-6-24 15:15:24
 */
@Data
@ColumnWidth(10)
public class EmployeeExportVO extends BaseEntity {

	private static final long serialVersionUID = 1L;

	@ExcelProperty(value = "员工主码")
	private String empCode;

	@ExcelProperty(value = "员工类型")
	private String empNatrue;

	@ExcelProperty(value = "姓名")
	private String empName;

	@ColumnWidth(20)
	@ExcelProperty(value = "身份证号")
	private String empIdcard;

	@ExcelProperty(value = "身份证开始日期")
	private LocalDateTime validityStart;

	@ExcelProperty(value = "身份证截止日期")
	private LocalDateTime validityEnd;

	@ExcelProperty(value = "婚姻状况")
	private String empMarriStatus;

	@ExcelProperty(value = "民族")
	private String empNational;

	@ExcelProperty(value = "政治面貌")
	private String politicalStatus;

	@ExcelProperty(value = "手机号码")
	private String empPhone;

	@ExcelProperty(value = "邮箱")
	private String empEmail;

	@ExcelProperty(value = "户籍所在省")
	private String idProvince;

	@ExcelProperty(value = "户籍所在市")
	private String idCity;

	@ExcelProperty(value = "户籍所在县")
	private String idTown;

	@ExcelProperty(value = "户口性质")
	private String empRegisType;

	@ExcelProperty(value = "档案所在省")
	private String fileProvince;

	@ExcelProperty(value = "档案所在市")
	private String fileCity;

	@ExcelProperty(value = "档案所在县")
	private String fileTown;

	@ExcelProperty(value = "是否大专及以上")
	private String isCollege;

	@ExcelProperty(value = "最高学历")
	private String hignEducation;

	@ExcelProperty(value = "学校")
	private String school;

	@ExcelProperty(value = "专业")
	private String major;

	@ExcelProperty(value = "入学时间")
	private LocalDateTime admissionDate;

	@ExcelProperty(value = "毕业时间")
	private LocalDateTime gradutionDate;

	@ExcelProperty(value = "档案备注")
	private String remark;

	/**
	 * 人员档案来源（字典：4人员档案新建、5项目档案新建、1社保/公积金、3商险、2薪酬）
	 */
	@ExcelProperty(value = "人员档案来源")
	private String fileSource;

	@ExcelProperty(value = "是否多项目")
	private String isProjects;

	@ExcelProperty(value = "现存项目数")
	private Integer projectNum;

	@ExcelProperty(value = "项目名称")
	private String deptName;

	@ExcelProperty(value = "项目编码")
	private String deptNo;

	/**
	 * 员工合同状态（字典）
	 */
	@ExcelProperty(value = "合同状态")
	private Integer contractStatus;

	/**
	 * 商险状态（字典）
	 */
	@ExcelProperty(value = "商险状态")
	private Integer insuranceStatus;

	/**
	 * 社保状态（字典）
	 */
	@ExcelProperty(value = "社保状态")
	private Integer socialStatus;

	/**
	 * 公积金状态（字典）
	 */
	@ExcelProperty(value = "公积金状态")
	private Integer fundStatus;

	/**
	 * 近3个月发薪（0否；1是）
	 */
	@ExcelProperty(value = "近3个月发薪")
	private Integer salaryStatus;

	@ExcelProperty(value = "创建人")
	private String createName;

	@ExcelProperty(value = "创建时间")
	private LocalDateTime proCreateTime;

	@ExcelProperty(value = "减档操作人")
	private String leaveUserName;

	@ExcelProperty(value = "减档时间")
	private LocalDateTime leaveTime;

	@ExcelProperty(value = "减档原因")
	private String leaveReason;

	@ExcelProperty(value = "减档备注")
	private String leaveRemark;

	/**
	 * 通信地址
	 */
	@ExcelProperty(value = "通信地址")
	private String contactAddress;

	@ExcelProperty(value = "单位名称")
	private String unitName;

	@ExcelProperty(value = "单位编码")
	private String unitNo;

}
